SystemOrganization addCategory: #ConfigurationOfLRSTM!

Object subclass: #ConfigurationOfLRSTM
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfLRSTM'!

!ConfigurationOfLRSTM class methodsFor: 'development support' stamp: 'StefanMarr 12/4/2011 13:25'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfLRSTM class methodsFor: 'private' stamp: 'StefanMarr 12/4/2011 13:25'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfLRSTM class methodsFor: 'private' stamp: 'StefanMarr 12/4/2011 13:25'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfLRSTM class methodsFor: 'private' stamp: 'StefanMarr 12/4/2011 13:25'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfLRSTM class methodsFor: 'metacello tool support' stamp: 'StefanMarr 12/4/2011 13:25'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfLRSTM class methodsFor: 'loading' stamp: 'StefanMarr 12/4/2011 13:25'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfLRSTM class methodsFor: 'loading' stamp: 'StefanMarr 12/4/2011 13:25'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfLRSTM class methodsFor: 'loading' stamp: 'StefanMarr 12/4/2011 13:25'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfLRSTM class methodsFor: 'accessing' stamp: 'StefanMarr 12/4/2011 13:25'!
project

	^self new project! !

!ConfigurationOfLRSTM class methodsFor: 'transporter' stamp: 'StefanMarr 12/4/2011 13:25'!
saveWithTransporter
	"Will save the package in file-out format using the Transporter infrastructure"
	self transporters
		ifNotNilDo: [:transporters | 
			transporters do: [:t | t saveNoPopup ]].! !

!ConfigurationOfLRSTM class methodsFor: 'transporter' stamp: 'StefanMarr 12/4/2011 13:25'!
subPackages
	"Specifies the names of all logical subpackages of the Benchmarking package."
	"TODO: have a versioning for this, to better comply with the Metacello approach."
	^ {	'SMark'.
		'Scripting'.
		'NPB'.
		'CL-Benchmarks-Game'.
	}! !

!ConfigurationOfLRSTM class methodsFor: 'transporter' stamp: 'StefanMarr 12/4/2011 13:25'!
transporters
	"Returns the transporters that define how to file out the different packages for versioning with Git."
	Smalltalk globals at: #Transporter ifPresent: [ :tpCls |
		^ self subPackages collect: [:pkg | tpCls forPackage: (PackageInfo named: pkg) ]
	].
	
	" Else "
	^ nil.! !

!ConfigurationOfLRSTM class methodsFor: 'transporter' stamp: 'StefanMarr 12/4/2011 13:25'!
transportersForFileOutMenu
	^ self transporters! !

!ConfigurationOfLRSTM class methodsFor: 'development support' stamp: 'StefanMarr 12/4/2011 13:25'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfLRSTM methodsFor: 'baselines' stamp: 'StefanMarr 12/7/2011 18:53'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
				
		"AST-Compiler (RBCompiler)"
		spec package: 'AST-Compiler' with: [
				spec repository: 'http://source.lukas-renggli.ch/helvetia'].
		
		"SMark Benchmarking"
		spec project: 'Benchmarking'
			with:
				[ spec
					className: 'ConfigurationOfBenchmarking';
					file: 'ConfigurationOfBenchmarking';
					repository: 'http://www.squeaksource.com/SMark' ].

		"LRSTM"
		spec
			repository: 'http://ss3.gemstone.com/ss/LRSTM';
			package: 'LRSTMPrerequisites';
			package: 'LRSTM' with: [
				spec 
					requires:   'AST-Compiler';
					requires:   'Benchmarking';
					requires:   'LRSTMPrerequisites'].
	].! !

!ConfigurationOfLRSTM methodsFor: 'symbolic versions' stamp: 'StefanMarr 12/4/2011 13:25'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.1'.
! !

!ConfigurationOfLRSTM methodsFor: 'accessing' stamp: 'StefanMarr 12/4/2011 13:25'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfLRSTM methodsFor: 'versions' stamp: 'StefanMarr 12/4/2011 13:30'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'StefanMarr'.
		spec timestamp: '2011-12-04 12:19'.
	].! !
